@@ -7,6 +7,7 @@ use crate::{Error, Migration, Report, Target};
 
 use async_trait::async_trait;
 use std::string::ToString;
+use time::format_description::well_known::Rfc3339;
 
 #[async_trait]
 pub trait AsyncTransaction {
@@ -42,8 +43,8 @@ async fn migrate<T: AsyncTransaction>(
         migration.set_applied();
         let update_query = &format!(
                 "INSERT INTO refinery_schema_history (version, name, applied_on, checksum) VALUES ({}, '{}', '{}', '{}')",
-                // safe to call unwrap as we just converted it to applied
-                migration.version(), migration.name(), migration.applied_on().unwrap().to_rfc3339(), migration.checksum().to_string());
+                // safe to call unwrap as we just converted it to applied, and we are sure it can be formatted according to RFC 33339
+                migration.version(), migration.name(), migration.applied_on().unwrap().format(&Rfc3339).unwrap(), migration.checksum().to_string());
         transaction
             .execute(&[
                 migration.sql().as_ref().expect("sql must be Some!"),
@@ -77,8 +78,8 @@ async fn migrate_grouped<T: AsyncTransaction>(
         migration.set_applied();
         let query = format!(
             "INSERT INTO refinery_schema_history (version, name, applied_on, checksum) VALUES ({}, '{}', '{}', '{}')",
-            // safe to call unwrap as we just converted migration to applied
-            migration.version(), migration.name(), migration.applied_on().unwrap().to_rfc3339(), migration.checksum().to_string()
+            // safe to call unwrap as we just converted it to applied, and we are sure it can be formatted according to RFC 33339
+            migration.version(), migration.name(), migration.applied_on().unwrap().format(&Rfc3339).unwrap(), migration.checksum().to_string()
         );
 
         let sql = migration.sql().expect("sql must be Some!").to_string();
